Module diff

Module diff 

Schema diff engine for comparing database schemas.

This module provides utilities to compare a current database schema against an expected schema and generate operations to bring them into alignment.

Structs

DiffWarning
A warning about a schema operation.
SchemaDiff
The result of comparing two schemas.
SchemaDiffer
Schema diff engine.

Enums

DestructivePolicy
How to handle destructive schema operations (drops, type changes).
SchemaOperation
A single schema modification operation.
WarningSeverity
Warning severity levels.

Functions

schema_diff
Compare two schemas and generate operations to transform current to expected.
schema_diff_with_policy
Compare two schemas and generate operations to transform current to expected.