pub fn schema_diff_with_policy(
current: &DatabaseSchema,
expected: &DatabaseSchema,
destructive_policy: DestructivePolicy,
) -> SchemaDiffExpand description
Compare two schemas and generate operations to transform current to expected.
pub fn schema_diff_with_policy(
current: &DatabaseSchema,
expected: &DatabaseSchema,
destructive_policy: DestructivePolicy,
) -> SchemaDiffCompare two schemas and generate operations to transform current to expected.