pub trait ModelTuple {
// Required method
fn all_table_schemas() -> Vec<TableInfo>;
// Provided method
fn database_schema(dialect: Dialect) -> DatabaseSchema { ... }
}Expand description
Trait for tuples of Models to aggregate their schemas.
This allows building a complete expected schema from multiple models.
Required Methods
Sourcefn all_table_schemas() -> Vec<TableInfo>
fn all_table_schemas() -> Vec<TableInfo>
Get all table schemas from this tuple of models.
Provided Methods
Sourcefn database_schema(dialect: Dialect) -> DatabaseSchema
fn database_schema(dialect: Dialect) -> DatabaseSchema
Build a complete database schema from all models in this tuple.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".