create_all

Function create_all 

pub async fn create_all<C: Connection>(
    cx: &Cx,
    conn: &C,
    schemas: &[&str],
) -> Outcome<(), Error>
Create all tables for the given models.

This is a convenience function for creating multiple tables in the correct order based on foreign key dependencies.