pub struct MigrationRunner { /* private fields */ }Expand description
Migration runner for executing migrations.
Implementations
Sourceimpl MigrationRunner
impl MigrationRunner
Sourcepub fn new(migrations: Vec<Migration>) -> Self
pub fn new(migrations: Vec<Migration>) -> Self
Create a new migration runner with the given migrations.
Sourcepub fn table_name(self, name: impl Into<String>) -> Self
pub fn table_name(self, name: impl Into<String>) -> Self
Set a custom migrations tracking table name.
The name is sanitized to only allow alphanumeric characters and underscores to prevent SQL injection.
Sourcepub async fn init<C: Connection>(&self, cx: &Cx, conn: &C) -> Outcome<(), Error>
pub async fn init<C: Connection>(&self, cx: &Cx, conn: &C) -> Outcome<(), Error>
Ensure the migrations tracking table exists.
Sourcepub async fn status<C: Connection>(
&self,
cx: &Cx,
conn: &C,
) -> Outcome<Vec<(String, MigrationStatus)>, Error>
pub async fn status<C: Connection>( &self, cx: &Cx, conn: &C, ) -> Outcome<Vec<(String, MigrationStatus)>, Error>
Get the status of all migrations.