Schema diff engine for comparing database schemas.
This module provides utilities to compare a current database schema against an expected schema and generate operations to bring them into alignment.
Structs
- Diff
Warning - A warning about a schema operation.
- Schema
Diff - The result of comparing two schemas.
- Schema
Differ - Schema diff engine.
Enums
- Destructive
Policy - How to handle destructive schema operations (drops, type changes).
- Schema
Operation - A single schema modification operation.
- Warning
Severity - Warning severity levels.
Functions
- schema_
diff - Compare two schemas and generate operations to transform current to expected.
- schema_
diff_ with_ policy - Compare two schemas and generate operations to transform current to expected.